# mmg_toolbox
Repository for useful python data analysis functions for the Diamond Magnetic Materials Group

[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![](https://img.shields.io/github/forks/DiamondLightSource/mmg_toolbox?label=GitHub%20Repo&style=social)](https://github.com/DiamondLightSource/mmg_toolbox)

**Version 0.4**

| By Dan Porter        | 
|----------------------|
| Diamond Light Source |
| 2024-2025            |

### Documentation
[diamondlightsource.github.io/mmg_toolbox](https://diamondlightsource.github.io/mmg_toolbox/)

### Installation
*Requires:* Python >=3.10, Numpy, h5py
```bash
python -m pip install --upgrade git+https://github.com/DanPorter/mmg_toolbox.git
```

### Usage
```python
from mmg_toolbox import start_gui

start_gui()
```

